# Aerosol Functions

A collection of functions to analyze atmospheric aerosol data.

Use [pip](https://pip.pypa.io/en/stable/) to install the package:
```
pip install aerosol-functions
```
Documentation can be found [here](https://jlpl.github.io/aerosol-functions/).

